import { getConsumers } from "@/app/lib/consumer/action";
import { Box } from "@chakra-ui/react";
import ConsumersTable from "./components/table";
import { usersRequestList } from "@/app/lib/users/action";
import { getIbcRequestList } from "@/app/lib/ibc/action";
import { SearchParamProps } from "@/types/searchParams";
import { prepareUsersDropdown } from "@/utils/common";
import { IbcInterface } from "@/types/settings/ibc/ibc";

const List = async ({ searchParams }: SearchParamProps) => {
  const [consumers, users, ibcs] = await Promise.all([
    getConsumers(searchParams),
    usersRequestList({pagination:'false'}),
    getIbcRequestList({pagination:'false'}),
  ]);

  // Prepare data for users dropdown
  const usersDropdown = prepareUsersDropdown(users);

  // Prepare data for ibcs dropdown
  const ibcsDropdown =
    ibcs?.data && ibcs.data.length > 0
      ? ibcs.data.map((ibc: IbcInterface) => ({
          label: `${ibc.area_name}`,
          value: ibc.id,
        }))
      : [];

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      {consumers?.data && (
        <ConsumersTable
          data={consumers?.data}
          users={usersDropdown}
          ibcs={ibcsDropdown}
        />
      )}
    </Box>
  );
};

export default List;
